#! perl -w
package main;
use strict;
use stkutils::ogf;
use stkutils::chunked_file;
use stkutils::ini_file;
use stkutils::debug;

my $ini = stkutils::ini_file->new('subst.ini', 'r');
if (!$ini) {stkutils::debug::fail(__PACKAGE__, __LINE__, '!$ini', 'cannot open subst.ini');};
if ($#{$ini->{sections_list}} == -1) {stkutils::debug::fail(__PACKAGE__, __LINE__, '$#{$ini->{sections_list}} == -1', 'subst.ini is empty - nothing to substitute');};
print "reading substitution parameters...\n";
my @subst;
foreach my $section (@{$ini->{sections_list}}) {
	my $sect = {};
	$sect->{name} = $section;
	$sect->{texture} = $ini->value($section, 'texture');
	$sect->{shader} = $ini->value($section, 'shader');
	push @subst, $sect;
}
$ini->close();
print "replacing textures and shaders...\n";
foreach my $model (@subst) {
	print "	$model->{name}\n";
	if (!(substr($model->{name}, 0, -3) eq 'ogf')) {
		$model->{name} .= '.ogf';
	}	
	my $ifh = stkutils::chunked_file->new($model->{name}, 'r');
	if (!$ifh) {stkutils::debug::fail(__PACKAGE__, __LINE__, '!$fh', 'cannot open '.$model->{name}.' to read');};
	my $ogf = stkutils::ogf->new();
	$ogf->read($ifh);
	$ogf->check_unhandled_chunks($ifh, $model->{name});
	$ifh->close();
	$ogf->{children}[0]->{texture_name} = $model->{texture} if defined $model->{texture};
	$ogf->{children}[0]->{shader_name} = $model->{shader} if defined $model->{shader};
	rename $model->{name}, $model->{name}.'.bak';
	my $ofh = stkutils::chunked_file->new($model->{name}, 'w');
	if (!$ofh) {stkutils::debug::fail(__PACKAGE__, __LINE__, '!$ofh', 'cannot open '.$model->{name}.' to write');};
	$ogf->write($ofh);
	$ofh->close();
}
print "done!\n";
